imblearn.over_sampling.SMOTE
============================

.. currentmodule:: imblearn.over_sampling

.. autoclass:: SMOTE

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SMOTE.__init__
      ~SMOTE.fit
      ~SMOTE.fit_sample
      ~SMOTE.get_params
      ~SMOTE.sample
      ~SMOTE.set_params
   
   

   
   
   